aboutsummaryrefslogtreecommitdiffstats
path: root/src/pcm/PcmExport.hxx
diff options
context:
space:
mode:
authorMax Kellermann <max@duempel.org>2014-08-31 16:12:26 +0200
committerMax Kellermann <max@duempel.org>2014-08-31 16:12:26 +0200
commite5a28bfd8d07fe5ca5dee1bfb55ce414c8f7e9fc (patch)
tree304e2b5bfa829d95d2c756449f010bcc76762eac /src/pcm/PcmExport.hxx
parent6e04d66a354c02910ebd849f2233e52de8b6e3c4 (diff)
downloadmpd-e5a28bfd8d07fe5ca5dee1bfb55ce414c8f7e9fc.tar.gz
mpd-e5a28bfd8d07fe5ca5dee1bfb55ce414c8f7e9fc.tar.xz
mpd-e5a28bfd8d07fe5ca5dee1bfb55ce414c8f7e9fc.zip
output/alsa, pcm: rename "DSD over USB" to "DoP"
The standard has been renamed since the early draft that was implemented in MPD.
Diffstat (limited to 'src/pcm/PcmExport.hxx')
-rw-r--r--src/pcm/PcmExport.hxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/pcm/PcmExport.hxx b/src/pcm/PcmExport.hxx
index 8169dad7b..b99a35835 100644
--- a/src/pcm/PcmExport.hxx
+++ b/src/pcm/PcmExport.hxx
@@ -35,11 +35,11 @@ template<typename T> struct ConstBuffer;
struct PcmExport {
/**
* The buffer is used to convert DSD samples to the
- * DSD-over-USB format.
+ * DoP format.
*
- * @see #dsd_usb
+ * @see #dop
*/
- PcmBuffer dsd_buffer;
+ PcmBuffer dop_buffer;
/**
* The buffer is used to pack samples, removing padding.
@@ -61,11 +61,11 @@ struct PcmExport {
uint8_t channels;
/**
* Convert DSD to DSD-over-USB? Input format must be
* SampleFormat::DSD and output format must be
* SampleFormat::S24_P32.
*/
- bool dsd_usb;
+ bool dop;
/**
* Convert (padded) 24 bit samples to 32 bit by shifting 8
@@ -93,10 +93,10 @@ struct PcmExport {
*
* This function cannot fail.
*
* @param channels the number of channels; ignored unless dsd_usb is set
*/
void Open(SampleFormat sample_format, unsigned channels,
- bool dsd_usb, bool shift8, bool pack, bool reverse_endian);
+ bool dop, bool shift8, bool pack, bool reverse_endian);
/**
* Calculate the size of one output frame.
@@ -61,11 +61,11 @@ struct PcmExport {
uint8_t channels;
/**
- * Convert DSD to DSD-over-USB? Input format must be
+ * Convert DSD to DSD-over-PCM (DoP)? Input format must be
* SampleFormat::DSD and output format must be
* SampleFormat::S24_P32.
@@ -93,10 +93,10 @@ struct PcmExport {
* This function cannot fail.
*
- * @param channels the number of channels; ignored unless dsd_usb is set
+ * @param channels the number of channels; ignored unless dop is set
*/
void Open(SampleFormat sample_format, unsigned channels,